@@ -36,8 +36,8 @@ setAs(from = "list", to = OPMA, function(from) {
   if (program %in% KNOWN_PROGRAMS)
     mat <- mat[unlist(map_grofit_names()), , drop = FALSE]
   else
-    warning("Unknown aggregation program '", program,
-      "' -- you might experience problems.")
+    warning("unknown aggregation program '", program,
+      "' -- you might experience problems")
   new(OPMA, csv_data = csv_data(opm), measurements = measurements(opm),
     metadata = metadata(opm), aggr_settings = settings, aggregated = mat)
 })
@@ -203,12 +203,7 @@ setMethod("try_opms", "list", function(object, precomputed = TRUE,
 #'
 opms <- function(..., precomputed = TRUE, skip = FALSE, group = FALSE) {
   opms_or_opm <- function(x)  {
-    if ((len <- length(x)) == 0L)
-      NULL
-    else if (len == 1L)
-      x[[1L]]
-    else
-      new(OPMS, plates = x)
+    case(length(x), NULL, x[[1L]], new(OPMS, plates = x))
   }
   if (is.character(group)) {
     wanted <- group
@@ -217,15 +212,15 @@ opms <- function(..., precomputed = TRUE, skip = FALSE, group = FALSE) {
     wanted <- NULL
     group <- as.logical(group)
   }
-  plates <- to_opm_list(list(...), precomputed = precomputed, skip = skip,
+  result <- to_opm_list(list(...), precomputed = precomputed, skip = skip,
     group = group)
   if (is.null(wanted)) {
     if (group)
-      lapply(plates, opms_or_opm)
+      lapply(result, opms_or_opm)
     else
-      opms_or_opm(plates)
+      opms_or_opm(result)
   } else
-    opms_or_opm(plates[[wanted]])
+    opms_or_opm(result[[wanted]])
 }
 
 
@@ -283,22 +278,27 @@ setGeneric("map_values",
 #'   \code{NULL} or an empty named character vector (if \code{mapping} is
 #'   missing). \code{object} may also belong to the virtual class
 #'   \code{\link{MOA}}, comprising matrices and arrays.
-#' @param mapping Character vector used as a mapping from its names to its
+#' @param mapping Character vector, function, formula, or missing.
+#'   If a character vector used as a mapping from its names to its
 #'   values. Values from \code{object} are searched for in the \code{names}
 #'   attribute of \code{mapping}; those found are replaced by the
-#'   corresponding values of \code{mapping}. If \code{mapping} is missing, a
+#'   corresponding values of \code{mapping}. 
+#'   If \code{mapping} is missing, a
 #'   character vector is returned (sorted and with duplicates removed) whose
 #'   names are identical to the values. This eases the construction of mapping
 #'   vectors specific for \code{object}. If \code{mapping} is missing, the
-#'   \code{coerce} argument must be named. \code{mapping} changes its usage
-#'   if \code{coerce} is \code{TRUE}. For \code{\link{MOA}} objects,
-#'   \code{mapping} can also be a function. The function would be applied to
+#'   \code{coerce} argument must be named. 
+#'   \code{mapping} changes its usage
+#'   if \code{coerce} is \code{TRUE}. For \code{\link{MOA}} objects, if
+#'   \code{mapping} was a function, it would be applied to
 #'   \code{object} after conversion with \code{as.vector}, and it would be
 #'   attempted to add the original attributes (particularly important are
 #'   \sQuote{dim} and \sQuote{dimnames} back to the result. For
 #'   \code{\link{MOA}} objects, if \code{mapping} is the usual character
 #'   vector, it then is used for mapping the \code{storage.mode}, not the
 #'   \code{class} of \code{object}.
+#'   \code{mapping} can also be a formula, it is then used to compute on lists.
+#'   The see examples below.
 #' @param coerce Character vector with the names of classes that are coerced to
 #'   \sQuote{character} to allow the mapping. Other classes are returned
 #'   unchanged. Note that the coerced data are \strong{not} converted back to
@@ -320,23 +320,23 @@ setGeneric("map_values",
 #'   because \code{\link{map_metadata}} is available.
 #' @examples
 #'
-#' # Character+character method
+#' # Character/character method
 #' map <- letters
 #' names(map) <- rev(LETTERS)
 #' (x <- map_values(LETTERS, map))
 #' stopifnot(rev(x) == letters)
 #'
-#' # Character+missing method
+#' # Character/missing method
 #' (x <- map_values(letters))
 #' stopifnot(x == letters, names(x) == letters)
 #'
-#' # Character+function method
+#' # Character/function method
 #' x <- letters[1:4]
 #' names(x) <- LETTERS[1:4]
 #' (y <- map_values(x, function(z) sprintf("%s%s", z, z)))
 #' stopifnot(names(y) == names(x), y != x)
 #'
-#' # List+character method
+#' # List/character method
 #' x <- list(a = 1:8, c = 9, d = 'x')
 #' map <- c(a = "b", e = "f", x = "y")
 #' (y <- map_values(x, map))
@@ -350,13 +350,13 @@ setGeneric("map_values",
 #' stopifnot(identical(x[1], y[1]), !identical(x[2], y[2]),
 #'   identical(x[3], y[3]))
 #'
-#' # List+function method
+#' # List/function method
 #' (y <- map_values(x, identity, coerce = "ANY"))
 #' stopifnot(identical(x, y))
 #' (y <- map_values(x, class, coerce = "ANY"))
 #' stopifnot(sapply(y, class) == "character", names(y) == names(x))
 #'
-#' # List+missing method
+#' # List/missing method
 #' (y <- map_values(x))
 #' stopifnot(y == "x", names(y) == y)
 #' (y <- map_values(x, coerce = "integer"))
@@ -368,7 +368,20 @@ setGeneric("map_values",
 #' (y <- map_values(x, coerce = TRUE))
 #' stopifnot(y == c("character", "integer", "numeric"), names(y) == y)
 #'
-#' # Data frame+character method
+#' # List/formula method
+#' (y <- map_values(x, ~ a + c))
+#' stopifnot(is.numeric(y), y == c(10:17))
+#' (y <- map_values(x, b ~ a + c))
+#' stopifnot(is.list(y), y$b == c(10:17))
+#'
+#' # List/formula method applied to a data frame
+#' x <- data.frame(a = 1:5, b = 6:10)
+#' (y <- map_values(x, c ~ a + b))
+#' stopifnot(is.data.frame(y), dim(y) == c(5, 3))
+#' (z <- map_values(x, ~ a + b))
+#' stopifnot(identical(z, y$c))
+#'
+#' # Data frame/character method
 #' x <- data.frame(a = 1:3, b = letters[1:3])
 #' stopifnot(sapply(x, class) == c("integer", "factor"))
 #' map <- c(a = "A", b = "B", c = "C", `1` = "5")
@@ -384,13 +397,13 @@ setGeneric("map_values",
 #' (y <- map_values(x, map, coerce = TRUE))
 #' stopifnot(sapply(y, class) == c("complex", "character"))
 #'
-#' # Data frame+function method
+#' # Data frame/function method
 #' (y <- map_values(x, `+`, coerce = "integer", y = 1L))
 #' stopifnot(y$a == x$a + 1L)
 #' (y <- map_values(x, as.character, coerce = "factor"))
 #' stopifnot(sapply(y, class) == c("integer", "character"))
 #'
-#' # Data frame+missing method
+#' # Data frame/missing method
 #' (y <- map_values(x))
 #' stopifnot(is.character(y), length(y) == 0)
 #' (y <- map_values(x, coerce = "factor"))
@@ -400,35 +413,35 @@ setGeneric("map_values",
 #' (y <- map_values(x, coerce = TRUE))
 #' stopifnot(is.character(y), y == c("factor", "integer"), names(y) == y)
 #'
-#' # Matrix+character method
+#' # Matrix/character method
 #' (x <- matrix(1:6, nrow = 2))
 #' (y <- map_values(x, c(integer = "numeric"), coerce = TRUE))
 #' stopifnot(storage.mode(x) != storage.mode(y))
 #' (y <- map_values(x, c(`1` = "7"), coerce = "integer"))
 #' stopifnot(is.character(y), y[-1] == x[-1])
 #'
-#' # Matrix+function method
+#' # Matrix/function method
 #' (y <- map_values(x, identity))
 #' stopifnot(identical(x, y))
 #' (y <- map_values(x, `+`, y = 1)) # useless because '+' is directly available
 #' stopifnot(dim(y) == dim(x), y == x + 1)
 #'
-#' # Matrix+missing method
+#' # Matrix/missing method
 #' (y <- map_values(x))
 #' stopifnot(y == "integer", names(y) == y)
 #' (y <- map_values(x, coerce = "ANY"))
 #' stopifnot(is.character(y), y == 1:6, names(y) == y)
 #'
-#' # Factor+function method
+#' # Factor/function method
 #' x <- as.factor(c("a", "b", "a"))
 #' (y <- map_values(x, toupper))
 #' stopifnot(is.factor(y), y == toupper(x))
 #'
-#' # Factor+character method
+#' # Factor/character method
 #' (y <- map_values(x, c(b = "c", k = "h")))
 #' stopifnot(is.factor(y), levels(y) == c("a", "c"))
 #'
-#' # Factor+missing method
+#' # Factor/missing method
 #' (y <- map_values(x))
 #' stopifnot(levels(x) == y, names(y) == y)
 #'
@@ -450,16 +463,12 @@ setMethod("map_values", c("list", "character"), function(object, mapping,
   map_values(object, mapping = mapfun, coerce = coerce)
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c("list", "function"), function(object, mapping,
     coerce = character(), ...) {
   rapply(object = object, f = mapping, classes = prepare_class_names(coerce),
     how = "replace", ...)
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c("list", "missing"), function(object,
     coerce = character()) {
   if (isTRUE(coerce)) {
@@ -472,8 +481,17 @@ setMethod("map_values", c("list", "missing"), function(object,
   map_values(rapply(object, mapfun, classes = classes))
 }, sealed = SEALED)
 
-#' @export
-#'
+setMethod("map_values", c("list", "formula"), function(object, mapping) {
+  if (length(mapping) > 2L) {
+    object[[parse_formula_head(mapping[[2L]])]] <- eval(expr = mapping[[3L]], 
+      envir = object)
+    object
+  } else
+    eval(expr = mapping[[2L]], envir = object)
+}, sealed = SEALED)
+
+#-------------------------------------------------------------------------------
+
 setMethod("map_values", c("data.frame", "function"), function(object, mapping,
     coerce = character(), ...) {
   if (identical("ANY", coerce <- prepare_class_names(coerce)))
@@ -483,8 +501,6 @@ setMethod("map_values", c("data.frame", "function"), function(object, mapping,
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c("data.frame", "character"), function(object, mapping,
     coerce = character()) {
   if (isTRUE(coerce)) {
@@ -496,8 +512,6 @@ setMethod("map_values", c("data.frame", "character"), function(object, mapping,
   map_values(object, mapping = mapfun, coerce = coerce)
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c("data.frame", "missing"), function(object,
     coerce = character()) {
   if (isTRUE(coerce))
@@ -511,8 +525,8 @@ setMethod("map_values", c("data.frame", "missing"), function(object,
   map_values(result)
 }, sealed = SEALED)
 
-#' @export
-#'
+#-------------------------------------------------------------------------------
+                                                               
 setMethod("map_values", c(MOA, "character"), function(object, mapping,
     coerce = TRUE) {
   if (isTRUE(coerce)) {
@@ -528,8 +542,6 @@ setMethod("map_values", c(MOA, "character"), function(object, mapping,
   }
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c(MOA, "missing"), function(object, coerce = TRUE) {
   if (isTRUE(coerce))
     result <- storage.mode(object)
@@ -542,16 +554,14 @@ setMethod("map_values", c(MOA, "missing"), function(object, coerce = TRUE) {
   map_values(result)
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c(MOA, "function"), function(object, mapping, ...) {
   result <- mapping(as.vector(object), ...)
   mostattributes(result) <- attributes(object)
   result
 }, sealed = SEALED)
 
-#' @export
-#'
+#-------------------------------------------------------------------------------
+                                                               
 setMethod("map_values", c("character", "function"), function(object, mapping,
     ...) {
   result <- mapping(object, ...)
@@ -559,50 +569,44 @@ setMethod("map_values", c("character", "function"), function(object, mapping,
   result
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c("character", "character"), function(object, mapping) {
   mapped <- match(object, names(mapping))
   object[found] <- mapping[mapped[found <- !is.na(mapped)]]
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c("character", "missing"), function(object) {
   object <- sort(unique(object))
   structure(.Data = object, .Names = object)
 }, sealed = SEALED)
 
-#' @export
-#'
+#-------------------------------------------------------------------------------                                                               
+                                                               
 setMethod("map_values", c("factor", "function"), function(object, mapping,
     ...) {
   levels(object) <- map_values(levels(object), mapping, ...)
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c("factor", "character"), function(object, mapping) {
   levels(object) <- map_values(levels(object), mapping)
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c("factor", "missing"), function(object) {
   map_values(levels(object))
 }, sealed = SEALED)
 
-#' @export
-#'
+#-------------------------------------------------------------------------------
+                                                               
+setMethod("map_values", c("NULL", "function"), function(object, mapping, ...) {
+  NULL
+}, sealed = SEALED)
+
 setMethod("map_values", c("NULL", "character"), function(object, mapping) {
   NULL
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_values", c("NULL", "missing"), function(object, mapping) {
   map_values(character())
 }, sealed = SEALED)
@@ -650,14 +654,14 @@ setGeneric("map_names",
 #'   because \code{\link{map_metadata}} is available.
 #' @examples
 #'
-#' # List+function method
+#' # List/function method
 #' x <- list(a = 1:8, c = 9, d = 'x')
 #' map <- function(x) sprintf("%s%s", x, x)
 #' (y <- map_names(x, map))
 #' stopifnot(identical(as.character(x), as.character(y)))
 #' stopifnot(!identical(names(x), names(y)))
 #'
-#' # List+character method
+#' # List/character method
 #' x <- list(a = 1:8, c = 9, d = 'x')
 #' map <- c(a = "b", e = "f", x = "y")
 #' (y <- map_names(x, map))
@@ -665,7 +669,7 @@ setGeneric("map_names",
 #' stopifnot(!identical(names(x), names(y)))
 #' # compare with the map_values() example
 #'
-#' # List+missing method
+#' # List/missing method
 #' x <- list(a = 1:8, c = 9, d = 'x')
 #' (y <- map_names(x))
 #' stopifnot(identical(as.vector(y), names(x)))
@@ -675,38 +679,37 @@ setGeneric("map_names",
 #' (y <- map_names(x))
 #' stopifnot(length(y) > length(names(x)))
 #'
-#' # Data frame+function method
+#' # Data frame/function method
 #' x <- data.frame(a = 1:3, b = letters[1:3])
 #' (y <- map_names(x, toupper))
 #' stopifnot(identical(y[[1]], x[[1]]), identical(y[[2]], x[[2]]))
 #' stopifnot(identical(names(y), c("A", "B")))
 #'
-#' # Data frame+character method
+#' # Data frame/character method
 #' (y <- map_names(x, c(a = "b", b = "a")))
 #' stopifnot(x == y, names(y) == c("b", "a"))
 #'
-#' # Data frame+missing method
+#' # Data frame/missing method
 #' (y <- map_names(x))
 #' stopifnot(is.character(y), y == names(y), length(y) == 5)
 #'
-#' # Matrix+function method
+#' # Matrix/function method
 #' x <- as.matrix(x)
 #' (y <- map_names(x, toupper))
 #' stopifnot(x == y, toupper(colnames(x)) == colnames(y))
 #'
-#' # Matrix+character method
+#' # Matrix/character method
 #' (y <- map_names(x, c(a = "b", b = "a")))
 #' stopifnot(x == y, colnames(y) == c("b", "a"))
 #'
-#' # Matrix+missing method
+#' # Matrix/missing method
 #' (y <- map_names(x))
 #' stopifnot(y == c("a", "b"), names(y) == y)
 #'
 setMethod("map_names", c("list", "function"), function(object, mapping, ...) {
   map_names_recursively <- function(item) {
     if (is.list(item)) {
-      if (!is.null(n <- names(item)))
-        names(item) <- mapping(n, ...)
+      names(item) <- map_values(names(item), mapping, ...)
       lapply(item, FUN = map_names_recursively)
     } else
       item
@@ -714,8 +717,6 @@ setMethod("map_names", c("list", "function"), function(object, mapping, ...) {
   map_names_recursively(object)
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_names", c("list", "character"), function(object, mapping) {
   map_names_recursively <- function(item) {
     if (is.list(item)) {
@@ -727,8 +728,6 @@ setMethod("map_names", c("list", "character"), function(object, mapping) {
   map_names_recursively(object)
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_names", c("list", "missing"), function(object) {
   get_names_recursively <- function(item) {
     if (is.list(item))
@@ -739,87 +738,51 @@ setMethod("map_names", c("list", "missing"), function(object) {
   map_values(get_names_recursively(object))
 }, sealed = SEALED)
 
-#' @export
-#'
+#-------------------------------------------------------------------------------
+
 setMethod("map_names", c("data.frame", "function"), function(object, mapping,
     ...) {
-  if (is.null(dn <- dimnames(object)))
-    return(object)
-  dimnames(object) <- lapply(dn, function(n) {
-    if (is.null(n))
-      n
-    else
-      mapping(n, ...)
-  })
+  dimnames(object) <- map_values(dimnames(object), mapping, ...)
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_names", c("data.frame", "character"), function(object, mapping) {
-  dimnames(object) <- if (is.null(dn <- dimnames(object)))
-    map_values(dn, mapping)
-  else
-    lapply(dn, map_values, mapping = mapping)
+  dimnames(object) <- map_values(dimnames(object), mapping)
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_names", c("data.frame", "missing"), function(object) {
   map_values(dimnames(object))
 }, sealed = SEALED)
 
-#' @export
-#'
-setMethod("map_names", c(MOA, "function"), function(object, mapping,
-    ...) {
-  if (is.null(dn <- dimnames(object)))
-    return(object)
-  dimnames(object) <- lapply(dn, function(n) {
-    if (is.null(n))
-      n
-    else
-      mapping(n, ...)
-  })
+#-------------------------------------------------------------------------------
+
+setMethod("map_names", c(MOA, "function"), function(object, mapping, ...) {
+  dimnames(object) <- map_values(dimnames(object), mapping, ...)
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_names", c(MOA, "character"), function(object, mapping) {
-  dimnames(object) <- if (is.null(dn <- dimnames(object)))
-    map_values(dn, mapping)
-  else
-    lapply(dn, map_values, mapping = mapping)
+  dimnames(object) <- map_values(dimnames(object), mapping)
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_names", c(MOA, "missing"), function(object) {
   map_values(dimnames(object))
 }, sealed = SEALED)
 
-#' @export
-#'
-setMethod("map_names", c("ANY", "function"), function(object, mapping,
-    ...) {
-  if (is.null(n <- names(object)))
-    return(object)
-  names(object) <- mapping(n, ...)
+#-------------------------------------------------------------------------------
+
+setMethod("map_names", c("ANY", "function"), function(object, mapping, ...) {
+  names(object) <- map_values(names(object), mapping, ...)
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_names", c("ANY", "character"), function(object, mapping) {
   names(object) <- map_values(names(object), mapping)
   object
 }, sealed = SEALED)
 
-#' @export
-#'
 setMethod("map_names", c("ANY", "missing"), function(object) {
   map_values(names(object))
 }, sealed = SEALED)
@@ -844,10 +807,12 @@ setGeneric("contains",
 #' the data list can be any of the values at the corresponding position in the
 #' query list, and the comparison is done by coercion to character vectors.
 #' An empty query list results in \code{TRUE}. Missing names in a non-empty
-#' query list result in \code{FALSE}.
+#' query list result in \code{FALSE}. There is also an \code{\link{OPMS}}
+#' method, which tests whether an \code{\link{OPM}} object is contained.
 #'
-#' @param object List containing the data.
-#' @param other List used as query.
+#' @param object List containing the data, or \code{\link{OPMS}} object.
+#' @param other For the list method, a list used as query; for the 
+#'   \code{\link{OPMS}} method, an \code{\link{OPM}} object used as query.
 #' @param values Logical scalar. Compare also the values or only the keys? If
 #'   \code{FALSE}, \code{exact} is ignored.
 #' @param exact Logical scalar. If \code{FALSE}, the data value(s) might by
@@ -856,15 +821,21 @@ setGeneric("contains",
 #'   correspond to the query value(s), and no coercion is done (see
 #'   \code{identical}) for details). This might be too strict for most
 #'   applications.
+#' @param ... Optional arguments passed to \code{identical} from the 
+#'   \pkg{base} package, allowing for fine-control of identity. Has no effect
+#'   unless \code{exact} is \code{TRUE}.
 #' @export
 #' @return Logical scalar.
 #' @family list-functions
 #' @seealso base::list base::as.list base::`[` base::`[[` base::match
+#' @seealso base::identity
 #' @keywords attribute list
 #' @note This function is not normally directly called by an \pkg{opm} user but
 #'   might be useful in other contexts. It forms the basis of a number of
 #'   metadata query functions.
 #' @examples
+#'
+#' # List/list method
 #' x <- list(a = 1:8, c = 9, d = list(d1 = 'x', d2 = 'y'))
 #' y <- list(a = 1:10, c = "9", d = list(d1 = "x"))
 #' stopifnot(contains(x, y))
@@ -872,8 +843,13 @@ setGeneric("contains",
 #' stopifnot(contains(x, y, exact = TRUE, values = FALSE))
 #' # see particularly infix-q and infix-k for more examples
 #'
+#' # OPMS/OPM method
+#' data(vaas_4)
+#' data(vaas_1)
+#' stopifnot(contains(vaas_4, vaas_1))
+#'
 setMethod("contains", c("list", "list"), function(object, other,
-    values = TRUE, exact = FALSE) {
+    values = TRUE, exact = FALSE, ...) {
   query.keys <- names(other)
   if (length(query.keys) == 0L && length(other) > 0L)
     return(FALSE)
@@ -885,14 +861,15 @@ setMethod("contains", c("list", "list"), function(object, other,
     data.subset <- object[[found[idx]]]
     result <- if (is.list(query.subset)) {
       if (is.list(data.subset))
-        Recall(data.subset, query.subset, values = values, exact = exact)
+        Recall(object = data.subset, other = query.subset, values = values,
+          exact = exact, ...)
       else if (values)
         FALSE
       else
         is.null(names(query.subset))
     } else if (values) {
       if (exact)
-        identical(data.subset, query.subset)
+        identical(x = data.subset, y = query.subset, ...)
       else
         all(data.subset %in% query.subset)
     } else
@@ -903,6 +880,13 @@ setMethod("contains", c("list", "list"), function(object, other,
   TRUE
 }, sealed = SEALED)
 
+setMethod("contains", c(OPMS, OPM), function(object, other, ...) {
+  for (plate in object@plates)
+    if (identical(x = plate, y = other, ...))
+      return(TRUE)
+  FALSE
+}, sealed = SEALED)
+
 
 ################################################################################
 ################################################################################
@@ -925,6 +909,7 @@ setGeneric("repair_na_strings",
 #' @param type Character scalar denoting the type to which input character
 #'   vectors shall be tried to be converted.
 #' @return Character vector or list.
+#' @seealso utils::type.convert
 #' @keywords internal
 #' @references \url{http://www.yaml.org/}
 #'
@@ -1040,6 +1025,7 @@ setGeneric("insert", function(object, ...) standardGeneric("insert"))
 #' @param ... Optional other items to insert.
 #' @param .force Logical scalar. Overwite items that are already there?
 #' @return List.
+#' @seealso utils::modifyList
 #' @keywords internal
 #'
 setMethod("insert", "list", function(object, other, ..., .force = FALSE) {
